==> ejc-wzxt-impl-3.0.0-20200928.082849-11-sources.jar: com/ejianc/business/wzxt/bean/CheckDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 验收明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="check_id")
    private java.lang.Long checkId; // 验收主键ID
    @TableField(value="delivery_id")
    private java.lang.Long deliveryId; // 发货主键ID
    @TableField(value="delivery_detail_id")
    private java.lang.Long deliveryDetailId; // 发货明细主键ID
    @TableField(value="order_id")
    private java.lang.Long orderId; // 订单主键ID
    @TableField(value="order_detail_id")
    private java.lang.Long orderDetailId; // 订单明细主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="deliver_nums_sum")
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    @TableField(value="check_nums_sum")
    private java.math.BigDecimal checkNumsSum; // 验收数量
    @TableField(value="material_manufacturer")
    private java.lang.String materialManufacturer; // 生产厂家
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    
    
    

    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 发货主键ID
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 发货明细主键ID
     */
    public java.lang.Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    /**
     * 发货明细主键ID
     */
    public void setDeliveryDetailId(java.lang.Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public java.lang.Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(java.lang.Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}

==> ejc-wzxt-impl-3.0.0-20201019.092613-49-sources.jar: com/ejianc/business/wzxt/bean/CheckDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 验收明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="check_id")
    private java.lang.Long checkId; // 验收主键ID
    @TableField(value="delivery_id")
    private java.lang.Long deliveryId; // 发货主键ID
    @TableField(value="delivery_detail_id")
    private java.lang.Long deliveryDetailId; // 发货明细主键ID
    @TableField(value="order_id")
    private java.lang.Long orderId; // 订单主键ID
    @TableField(value="order_detail_id")
    private java.lang.Long orderDetailId; // 订单明细主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="deliver_nums_sum")
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    @TableField(value="check_nums_sum")
    private java.math.BigDecimal checkNumsSum; // 验收数量
    @TableField(value="material_manufacturer")
    private java.lang.String materialManufacturer; // 生产厂家
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="instore_id")
    private java.lang.String instoreId; // 入库单主键
    @TableField(value="instore_detail_id")
    private java.lang.String instoreDetailId; // 入库单明细主键
    @TableField(value="instore_num")
    private java.math.BigDecimal instoreNum; // 入库数量
    
    

    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 发货主键ID
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 发货明细主键ID
     */
    public java.lang.Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    /**
     * 发货明细主键ID
     */
    public void setDeliveryDetailId(java.lang.Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public java.lang.Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(java.lang.Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 入库单主键
     */
    public java.lang.String getInstoreId() {
        return instoreId;
    }

    /**
     * 入库单主键
     */
    public void setInstoreId(java.lang.String instoreId) {
        this.instoreId = instoreId;
    }
    /**
     * 入库单明细主键
     */
    public java.lang.String getInstoreDetailId() {
        return instoreDetailId;
    }

    /**
     * 入库单明细主键
     */
    public void setInstoreDetailId(java.lang.String instoreDetailId) {
        this.instoreDetailId = instoreDetailId;
    }
    /**
     * 入库数量
     */
    public java.math.BigDecimal getInstoreNum() {
        return instoreNum;
    }

    /**
     * 入库数量
     */
    public void setInstoreNum(java.math.BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
}
